==> deal.ii_9.2.0.orig.tar.xz: deal.ii-9.2.0/source/base/mpi_consensus_algorithms.cc <==
// ---------------------------------------------------------------------
//
// Copyright (C) 2005 - 2020 by the deal.II authors
//
// This file is part of the deal.II library.
//
// The deal.II library is free software; you can use it, redistribute
// it, and/or modify it under the terms of the GNU Lesser General
// Public License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
// The full text of the license can be found in the file LICENSE.md at
// the top level directory of deal.II.
//
// ---------------------------------------------------------------------

#include <deal.II/base/mpi_consensus_algorithms.templates.h>

DEAL_II_NAMESPACE_OPEN

namespace Utilities
{
  namespace MPI
  {
    namespace ConsensusAlgorithms
    {
      template class Process<unsigned int, unsigned int>;

      template class NBX<unsigned int, unsigned int>;

      template class PEX<unsigned int, unsigned int>;

      template class Selector<unsigned int, unsigned int>;


      template class Process<
        std::pair<types::global_dof_index, types::global_dof_index>,
        unsigned int>;

      template class Selector<
        std::pair<types::global_dof_index, types::global_dof_index>,
        unsigned int>;

      template class NBX<
        std::pair<types::global_dof_index, types::global_dof_index>,
        unsigned int>;

      template class PEX<
        std::pair<types::global_dof_index, types::global_dof_index>,
        unsigned int>;

    } // namespace ConsensusAlgorithms
  }   // end of namespace MPI
} // end of namespace Utilities

DEAL_II_NAMESPACE_CLOSE

==> deal.ii_9.3.2.orig.tar.xz: deal.ii-9.3.2/source/base/mpi_consensus_algorithms.cc <==
// ---------------------------------------------------------------------
//
// Copyright (C) 2005 - 2021 by the deal.II authors
//
// This file is part of the deal.II library.
//
// The deal.II library is free software; you can use it, redistribute
// it, and/or modify it under the terms of the GNU Lesser General
// Public License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
// The full text of the license can be found in the file LICENSE.md at
// the top level directory of deal.II.
//
// ---------------------------------------------------------------------

#include <deal.II/base/mpi_consensus_algorithms.templates.h>

DEAL_II_NAMESPACE_OPEN

namespace Utilities
{
  namespace MPI
  {
    namespace ConsensusAlgorithms
    {
      template class Process<unsigned int, unsigned int>;

      template class NBX<unsigned int, unsigned int>;

      template class PEX<unsigned int, unsigned int>;

      template class Serial<unsigned int, unsigned int>;

      template class Selector<unsigned int, unsigned int>;


      template class Process<
        std::pair<types::global_dof_index, types::global_dof_index>,
        unsigned int>;

      template class Selector<
        std::pair<types::global_dof_index, types::global_dof_index>,
        unsigned int>;

      template class NBX<
        std::pair<types::global_dof_index, types::global_dof_index>,
        unsigned int>;

      template class Serial<
        std::pair<types::global_dof_index, types::global_dof_index>,
        unsigned int>;

      template class PEX<
        std::pair<types::global_dof_index, types::global_dof_index>,
        unsigned int>;

#ifdef DEAL_II_WITH_64BIT_INDICES
      template class Process<types::global_dof_index, unsigned int>;

      template class NBX<types::global_dof_index, unsigned int>;

      template class Serial<types::global_dof_index, unsigned int>;

      template class PEX<types::global_dof_index, unsigned int>;

      template class Selector<types::global_dof_index, unsigned int>;
#endif

      template class Process<char, char>;

      template class NBX<char, char>;

      template class PEX<char, char>;

      template class Serial<char, char>;

      template class Selector<char, char>;

    } // namespace ConsensusAlgorithms
  }   // end of namespace MPI
} // end of namespace Utilities

DEAL_II_NAMESPACE_CLOSE
